Home
last modified time | relevance | path

Searched refs:test_hd (Results 1 – 4 of 4) sorted by relevance

/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Dusual-deallocators.cu82 test_hd<H1D1>(t); in tests_hd()
83 test_hd<h1D1>(t); in tests_hd()
85 test_hd<H1d1>(t); in tests_hd()
87 test_hd<H1D2>(t); in tests_hd()
88 test_hd<H2D1>(t); in tests_hd()
89 test_hd<H2D2>(t); in tests_hd()
90 test_hd<H1D1D2>(t); in tests_hd()
91 test_hd<H1H2D1>(t); in tests_hd()
92 test_hd<H1H2D1>(t); in tests_hd()
93 test_hd<H1H2D2>(t); in tests_hd()
[all …]
H A Daddr-of-overloaded-fn.cu11 __host__ __device__ void test_hd() { in test_hd() function
/llvm-project-15.0.7/clang/test/CodeGenCUDA/
H A Dusual-deallocators.cu75 __host__ __device__ void test_hd(void *p) { in test_hd() function
84 test_hd<H1D1>(t); in tests_hd()
88 test_hd<H1D2>(t); in tests_hd()
92 test_hd<H2D1>(t); in tests_hd()
95 test_hd<H2D2>(t); in tests_hd()
98 test_hd<H1D1D2>(t); in tests_hd()
101 test_hd<H1H2D1>(t); in tests_hd()
105 test_hd<H1H2D2>(t); in tests_hd()
108 test_hd<H1H2D1D2>(t); in tests_hd()
/llvm-project-15.0.7/llvm/docs/
H A DCompileCudaWithLLVM.rst382 __host__ __device__ void test_hd() {